#include "lpc2103.h"
#include "config.h"
#include "types.h"
#include "timer.h"
#include "armVIC.h"
#include "sysInit.h"

volatile unsigned long timeval;
volatile unsigned long delayval;

void tc0_cmp(void) __attribute__((naked));

/* Timer0 Compare-Match Interrupt Handler (ISR) */
void tc0_cmp(void) 
{
	ISR_ENTRY();
	
	timeval++;
	delayval++;

    if( !(timeval%10) ) FIOSET = LED;
    else FIOCLR = LED;

	T0IR = TIR_MR0I; // Clear interrupt flag by writing 1 to Bit 0
	VICVectAddr = 0; // Acknowledge Interrupt (rough?)
	
	ISR_EXIT();
}

/* Setup Timer0 Compare-Match Interrupt         */
/* no prescaler timer runs at cclk = FOSC*PLL_M */
void initTimer(void) {
	timeval=0;
    delayval=0;
	T0TCR = TCR_RESET;      // reset timer 0
	T0PR = 0;               // set the prescale divider
	T0MR0 = ((FOSC*PLL_MUL)/(1000/10))-1;     // Compare-hit at 10mSec (-1 reset "tick")
	T0MCR = TMCR_MR0_I | TMCR_MR0_R;// Interrupt and Reset on MR0
	T0TCR = TCR_ENABLE;            // Timer0 Enable
	VICIntSelect &= ~VIC_BIT(VIC_TIMER0);
	VICVectAddr2 = (unsigned long)tc0_cmp;   // set interrupt vector in 2
	VICVectCntl2 = VIC_ENABLE | VIC_TIMER0; // use it for Timer 2 Interrupt:
	VICIntEnable = VIC_BIT(VIC_TIMER0);
}

/******************************************************************************
 *
 * Function Name: delayUs
 *
 * Description:
 *    wartet bis eingetragene Zeit in s vorbei ist
 *
 * 
 * Returns:
 *    void
 *
 *****************************************************************************/
void delayUs(uint32_t delay_US)
{
	delayval=0;
	uint32_t startTime = T0TC+delayval*T0MR0;
	uint32_t volatile endTime=startTime+58*delay_US;
	if(delay_US>5) while (endTime > T0TC+delayval*T0MR0);
}

void delayMs(uint32_t delay_MS)
{
	delayval=0;
	uint32_t startTime = T0TC+delayval*T0MR0;
	uint32_t volatile endTime=startTime+58981*delay_MS;
	if(delay_MS>0) while (endTime > T0TC+delayval*T0MR0);
}

uint32_t getTimer(void)
{
	return timeval*T0MR0+T0TC;
}

void setTimer(uint32_t val)
{
	T0TC=0;
	timeval=val;
	T0TC=0;
}
